@@ -13,7 +13,7 @@ def transcription(audio_path):
 	# load audio
 	speech, rate = librosa.load(audio_path,sr=16000)
 
-	inputs_values = my_processor(speech, sampling_rate=16_000, return_tensors="pt", padding=True).input_values
+	input_values = my_processor(speech, sampling_rate=16_000, return_tensors="pt", padding=True).input_values
 
 	with torch.no_grad():
   		logits = my_model(input_values, attention_mask=inputs.attention_mask).logits
